#[non_exhaustive]pub enum WeightError {
InvalidInput,
InvalidWeight,
InsufficientNonZero,
Overflow,
}Expand description
Invalid weight errors
This type represents errors from WeightedIndex::new,
WeightedIndex::update_weights and other weighted distributions.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
InvalidInput
The input weight sequence is empty, too long, or wrongly ordered
InvalidWeight
A weight is negative, too large for the distribution, or not a valid number
InsufficientNonZero
Not enough non-zero weights are available to sample values
When attempting to sample a single value this implies that all weights
are zero. When attempting to sample amount values this implies that
less than amount weights are greater than zero.
Overflow
Overflow when calculating the sum of weights