pub struct NormalInverseGaussian<F>{ /* private fields */ }Expand description
The normal-inverse Gaussian distribution NIG(α, β).
This is a continuous probability distribution with two parameters,
α (alpha) and β (beta), defined in (-∞, ∞).
It is also known as the normal-Wald distribution.
Plot
The following plot shows the normal-inverse Gaussian distribution with various values of α and β.
Example
use rand_distr::{NormalInverseGaussian, Distribution};
let norm_inv_gauss = NormalInverseGaussian::new(2.0, 1.0).unwrap();
let v = norm_inv_gauss.sample(&mut rand::rng());
println!("{} is from a normal-inverse Gaussian(2, 1) distribution", v);Implementations
Sourceimpl<F> NormalInverseGaussian<F>
impl<F> NormalInverseGaussian<F>
Sourcepub fn new(alpha: F, beta: F) -> Result<NormalInverseGaussian<F>, Error>
pub fn new(alpha: F, beta: F) -> Result<NormalInverseGaussian<F>, Error>
Construct a new NormalInverseGaussian distribution with the given alpha (tail heaviness) and
beta (asymmetry) parameters.
Note: If subnormal numbers are not supported or are disabled, this sampler may panic or produce incorrect output if alpha is close to the maximum finite float value.