pub struct UnitDisc;Expand description
Samples uniformly from the unit disc in two dimensions.
Implemented via rejection sampling.
For a distribution that samples only from the circumference of the unit disc,
see UnitCircle.
For a similar distribution in three dimensions, see UnitBall.
Plot
The following plot shows the unit disc. This distribution samples individual points from the entire area of the disc.
Example
use rand_distr::{UnitDisc, Distribution};
let v: [f64; 2] = UnitDisc.sample(&mut rand::rng());
println!("{:?} is from the unit Disc.", v)Trait Implementations
impl Copy for UnitDisc
Sourceimpl<F> Distribution<[F; 2]> for UnitDiscwhere
F: Float + SampleUniform,
impl<F> Distribution<[F; 2]> for UnitDiscwhere
F: Float + SampleUniform,